@@ -5,6 +5,8 @@ import struct
 import binascii
 import random
 import sys
+import logging
+
 
 # Python3 compatibility
 if sys.version_info < (3, ):
@@ -35,11 +37,20 @@ async def aes_cbc_decrypt(data, key):
 
 
 async def aes_cbc_encrypt_a32(data, key):
-    return await str_to_a32(await aes_cbc_encrypt(await a32_to_str(data), await a32_to_str(key)))
+    a = await a32_to_str(data)
+    b = await a32_to_str(key)
+    i = await aes_cbc_encrypt(a, b)
+    x = await str_to_a32(i)
+    logging.info(x)
+    return x
 
 
 async def aes_cbc_decrypt_a32(data, key):
-    return await str_to_a32(await aes_cbc_decrypt(await a32_to_str(data), await a32_to_str(key)))
+    a = await a32_to_str(data)
+    b = await a32_to_str(key)
+    i = await aes_cbc_decrypt(a, b)
+    x = await str_to_a32(i)
+    return x
 
 
 async def stringhash(str, aeskey):
@@ -49,7 +60,8 @@ async def stringhash(str, aeskey):
         h32[i % 4] ^= s32[i]
     for r in range(0x4000):
         h32 = await aes_cbc_encrypt_a32(h32, aeskey)
-    return await a32_to_base64((h32[0], h32[2]))
+    x = await a32_to_base64((h32[0], h32[2]))
+    return x
 
 
 async def prepare_key(arr):
@@ -65,12 +77,12 @@ async def prepare_key(arr):
 
 
 async def encrypt_key(a, key):
-    return sum(((await aes_cbc_encrypt_a32(a[i:i + 4]).collect(), key)
+    return sum(((await aes_cbc_encrypt_a32(a[i:i + 4]), key)
                 for i in range(0, len(a), 4)), ())
 
 
 async def decrypt_key(a, key):
-    return sum(((await aes_cbc_decrypt_a32(a[i:i + 4]).collect(), key)
+    return sum(((await aes_cbc_decrypt_a32(a[i:i + 4]), key)
                 for i in range(0, len(a), 4)), ())
 
 
@@ -78,7 +90,9 @@ async def encrypt_attr(attr, key):
     attr = await makebyte('MEGA' + json.dumps(attr))
     if len(attr) % 16:
         attr += b'\0' * (16 - len(attr) % 16)
-    return await aes_cbc_encrypt(attr, await a32_to_str(key))
+    a = await a32_to_str(key)
+    x = await aes_cbc_encrypt(attr, a)
+    return x
 
 
 async def decrypt_attr(attr, key):
@@ -134,7 +148,9 @@ async def base64_url_decode(data):
 
 
 async def base64_to_a32(s):
-    return await str_to_a32(await base64_url_decode(s))
+    a = await base64_url_decode(s)
+    x = await str_to_a32(a)
+    return x
 
 
 async def base64_url_encode(data):
@@ -146,7 +162,9 @@ async def base64_url_encode(data):
 
 
 async def a32_to_base64(a):
-    return await base64_url_encode(await a32_to_str(a))
+    i = await a32_to_str(a)
+    x = await base64_url_encode(i)
+    return x
 
 
 async def get_chunks(size):
